@@ -903,29 +903,23 @@ namespace Lum {
     */
     void SystemTime::Sub(const SystemTime& interval)
     {
+      if (time.tv_sec<interval.time.tv_sec ||
+        (time.tv_sec==interval.time.tv_sec && time.tv_usec<interval.time.tv_usec)) {
+        time.tv_sec=0;
+        time.tv_usec=0;
+        return;
+      }
+
+
       if (time.tv_usec<interval.time.tv_usec) {
         time.tv_usec=time.tv_usec+1000000-interval.time.tv_usec;
-
-        if (time.tv_sec>0) {
-          time.tv_sec--;
-        }
-        else {
-          time.tv_sec=0;
-          time.tv_usec=0;
-          return;
-        }
+        time.tv_sec--;
       }
       else {
         time.tv_usec=time.tv_usec-interval.time.tv_usec;
       }
 
-      if (time.tv_sec>=interval.time.tv_sec) {
-        time.tv_sec-=interval.time.tv_sec;
-      }
-      else {
-        time.tv_sec=0;
-        time.tv_usec=0;
-      }
+      time.tv_sec-=interval.time.tv_sec;
     }
 
     /**
