@@ -568,10 +568,8 @@ namespace Lum {
         }
       }
       else {
-        // TODO: Improve using Path class instance comparison
-        if (entry.type==Model::Dir::dirType && newPath.GetPath()==full->Get()) {
+        if (entry.type==Model::Dir::dirType) {
           newPath.AppendDir(entry.name);
-          newPath.SetBaseName(L"");
           path->Set(newPath);
         }
         else {
